@@ -749,6 +749,41 @@ def ODS_FRF_averaging(roving_responses, reference, no_of_avg):
     
     return ODS_FRFs
 
+def runup_data(time, signal, block_lenght=1, upper_frequency=100, plot=True):
+    """
+    Function for calculating run-up diagram data from time and signal time series.
+    :param time: Time series.
+    :type time: array
+    :param signal: Signal time series.
+    :type signal: array
+    :param block_lenght: Lenght of each time block for run-up diagram.
+    :type block_lenght: int, optional
+    :param upper_frequency: Maximum frequency in run-up diagram.
+    :type upper_frequency: int, optional
+    :param plot: Function returns a run-up plot or run-up data.
+    :type plot: bool, optional
+    """
+    
+    N = time.shape[0]
+    dt = time[1] - time[0]    
+    T = int(max(time)//block_lenght)
+    
+    freq = np.fft.rfftfreq(N//T,dt)
+    ind = np.argmin(np.abs(freq-upper_frequency))
+    
+    Acc_f = np.zeros((T,(N//T)//2+1), dtype=complex)
+
+    for i in range(T):
+        acc_f = signal[i*(N//T):(i+1)*(N//T)]
+        Acc_f[i,:] = np.fft.rfft(acc_f)*2/(N//T)
+
+    Acc_f_dB = 20*np.log10(np.abs(Acc_f/10**-6))
+    
+    if plot==True:
+        return contour_plot(np.arange(T)*block_lenght, freq[:ind], np.abs(Acc_f_dB).T[:ind])
+    else:
+        return np.arange(T)*block_lenght, freq[:ind], Acc_f.T[:ind], Acc_f_dB.T[:ind]
+
 #if necessary, font properties can be changed
 #def font():
 #    font = "Sans Serif"
@@ -1224,4 +1259,37 @@ def tranfer_path(freq, u3_partial, width=700, height=150):
             strokeWidth=0
         ).properties(width=width, height=height)
     
-    return A
\ No newline at end of file
+    return A
+
+
+def contour_plot(x, y, z, width=200, height=200, title='', cmap='turbo'):
+    """
+    Wrapper function for contour plot using Altair.
+    :param x: Values of x coordinates.
+    :type x: array
+    :param y: Values of y coordinates.
+    :type x: array
+    :param z: Image data.
+    :type x: 2D array
+    :param width: Width of the plot.
+    :type width: int, optional
+    :param height: Height of the plot.
+    :type height: int, optional
+    :param title: Title of the plot.
+    :type title: str, optional
+    :param cmap: Colormap.
+    :type cmap: str, optional
+    """
+        
+    xx, yy = np.meshgrid(x, y)
+    
+    df = pd.DataFrame({'x': xx.ravel(), 'y': yy.ravel(), 'value': z.ravel()})
+    
+    imshow = alt.Chart(df, title=title).mark_rect().encode(
+            alt.X('x:O', axis=alt.Axis(title='Time')),
+            alt.Y('y:O', axis=alt.Axis(title='Frequency'), scale=alt.Scale(reverse=True)),
+            color=alt.Color('value:Q', scale=alt.Scale(scheme=cmap), legend=alt.Legend(title="Value")),
+            tooltip=['x', 'y', alt.Text('value:Q', format=',.2f')]
+        ).properties(width=width, height=height)
+    
+    return imshow
\ No newline at end of file
